<?php
/**
 * Plugin Name: 特定のユーザーでログインすると特定のテーマでサイトが表示されるプラグイン
 * Description: Sets a specific theme for certain users when logged in to the WordPress dashboard
 * Version:     1.0.0
 */

// Add custom settings to the user profile page
add_action( 'show_user_profile', 'cdt_add_user_theme_settings' );
add_action( 'edit_user_profile', 'cdt_add_user_theme_settings' );

function cdt_add_user_theme_settings( $user ) {

    // Get the saved theme option for the user, if any
    $user_theme = get_user_meta( $user->ID, 'cdt_user_theme', true );

    // Output the theme selector input field
    ?>
    <h3><?php _e( 'Custom Dashboard Theme', 'cdt_domain' ); ?></h3>

    <table class="form-table">

        <tr>
            <th><label for="cdt_select_theme"><?php _e( 'Choose a theme', 'cdt_domain' ); ?></label></th>

            <td>
                <select name="cdt_user_theme" id="cdt_select_theme">
                    <?php
                        // Get all installed themes and loop through them
                        foreach ( wp_get_themes() as $theme ) {
                            // Set the selected attribute if the theme matches the saved option for the user
                            $selected = selected( $user_theme, $theme->get_stylesheet(), false );
                            ?>
                            <option value="<?php echo esc_attr( $theme->get_stylesheet() ); ?>" <?php echo $selected; ?>><?php echo esc_html( $theme->get( 'Name' ) ); ?></option>
                            <?php
                        }
                    ?>
                </select>
            </td>
        </tr>

    </table>
    <?php
}

// Save the custom user theme option when the user profile is updated
add_action( 'personal_options_update', 'cdt_save_user_theme_settings' );
add_action( 'edit_user_profile_update', 'cdt_save_user_theme_settings' );

function cdt_save_user_theme_settings( $user_id ) {
    // Check if the current user can edit the profile
    if ( !current_user_can( 'edit_user', $user_id ) ) {
        return;
    }

    // Update the user meta with the selected theme
    update_user_meta( $user_id, 'cdt_user_theme', $_POST['cdt_user_theme'] );
}

// Load the custom dashboard theme when a user is logged in and their theme option is set
add_filter( 'pre_option_template', 'cdt_load_custom_dashboard_theme' );
add_filter( 'pre_option_stylesheet', 'cdt_load_custom_dashboard_theme' );

function cdt_load_custom_dashboard_theme( $theme ) {
    // Get the user ID of the currently logged in user
    $current_user_id = get_current_user_id();

    // Check if the user ID is valid and their custom theme option is set
    if ( $current_user_id && $user_theme = get_user_meta( $current_user_id, 'cdt_user_theme', true ) ) {

        // Get the theme object for the selected custom theme
        $custom_theme = wp_get_theme( $user_theme );

        // If the custom theme is valid, use it instead of the default theme
        if ( is_object( $custom_theme ) && $custom_theme->exists() ) {
            $theme = $user_theme;
        }
    }

    return $theme;
}